@@ -58,7 +58,7 @@ catArgGroup.add_argument(
 # -----------------------------------------------------------------------------
 masArgGroup = aiServiceinstallArgParser.add_argument_group("Aibroker Basic Configuration")
 masArgGroup.add_argument(
-    "-i", "--aibroker-instance-id",
+    "-i", "--aiservice-instance-id",
     required=False,
     help="Aibroker Instance ID"
 )
@@ -166,7 +166,7 @@ mongoArgGroup.add_argument(
 masAppsArgGroup = aiServiceinstallArgParser.add_argument_group("MAS Applications")
 
 masAppsArgGroup.add_argument(
-    "--aibroker-channel",
+    "--aiservice-channel",
     required=False,
     help="Subscription channel for Maximo Ai Broker"
 )
@@ -174,162 +174,187 @@ masAppsArgGroup.add_argument(
 # AI Broker
 # -----------------------------------------------------------------------------
 aibrokerArgGroup = aiServiceinstallArgParser.add_argument_group("Maximo AI Broker")
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-storage-provider",
-    dest="mas_aibroker_storage_provider",
+
+
+# S3 - Minio
+# -----------------------------------------------------------------------------
+s3ArgGroup = aiServiceinstallArgParser.add_argument_group("S3 Storage")
+s3ArgGroup.add_argument(
+    "--install-minio",
+    dest="install_minio_aiservice",
     required=False,
-    help="Customize Manage database encryption keys"
+    help="Install Minio and configure it as the S3 provider for AI Service",
+    action="store_const",
+    const="true"
 )
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-storage-accesskey",
-    dest="mas_aibroker_storage_accesskey",
-    required=False,
-    help="Customize Manage database encryption keys"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-storage-secretkey",
-    dest="mas_aibroker_storage_secretkey",
-    required=False,
-    help="Customize Manage database encryption keys"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-storage-host",
-    dest="mas_aibroker_storage_host",
-    required=False,
-    help="Customize Manage database encryption keys"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-storage-port",
-    dest="mas_aibroker_storage_port",
-    required=False,
-    help="Customize Manage database encryption keys"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-storage-ssl",
-    dest="mas_aibroker_storage_ssl",
-    required=False,
-    help="Customize Manage database encryption keys"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-storage-region",
-    dest="mas_aibroker_storage_region",
-    required=False,
-    help="Customize Manage database encryption keys"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-storage-pipelines-bucket",
-    dest="mas_aibroker_storage_pipelines_bucket",
-    required=False,
-    help="Customize Manage database encryption keys"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-storage-tenants-bucket",
-    dest="mas_aibroker_storage_tenants_bucket",
-    required=False,
-    help="Customize Manage database encryption keys"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-storage-templates-bucket",
-    dest="mas_aibroker_storage_templates_bucket",
-    required=False,
-    help="Customize Manage database encryption keys"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-tenant-name",
-    dest="mas_aibroker_tenant_name",
-    required=False,
-    help="Customize Manage database encryption keys"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-watsonxai-apikey",
-    dest="mas_aibroker_watsonxai_apikey",
-    required=False,
-    help="Customize Manage database encryption keys"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-watsonxai-url",
-    dest="mas_aibroker_watsonxai_url",
-    required=False,
-    help="Customize Manage database encryption keys"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-watsonxai-project-id",
-    dest="mas_aibroker_watsonxai_project_id",
-    required=False,
-    help="Customize Manage database encryption keys"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-watsonx-action",
-    dest="mas_aibroker_watsonx_action",
-    required=False,
-    help="Customize Manage database encryption keys"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-db-host",
-    dest="mas_aibroker_db_host",
-    required=False,
-    help="Customize Manage database encryption keys"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-db-port",
-    dest="mas_aibroker_db_port",
-    required=False,
-    help="Customize Manage database encryption keys"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-db-user",
-    dest="mas_aibroker_db_user",
-    required=False,
-    help="Customize Manage database encryption keys"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-db-database",
-    dest="mas_aibroker_db_database",
-    required=False,
-    help="Customize Manage database encryption keys"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-db-secret-name",
-    dest="mas_aibroker_db_secret_name",
-    required=False,
-    help="Customize Manage database encryption keys"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-db-secret-key",
-    dest="mas_aibroker_db_secret_key",
-    required=False,
-    help="Customize Manage database encryption keys"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-db-secret-value",
-    dest="mas_aibroker_db_secret_value",
-    required=False,
-    help="Customize Manage database encryption keys"
-)
-aibrokerArgGroup.add_argument(
+
+s3ArgGroup.add_argument(
     "--minio-root-user",
     dest="minio_root_user",
     required=False,
     help="Root user for minio"
 )
-aibrokerArgGroup.add_argument(
+s3ArgGroup.add_argument(
     "--minio-root-password",
     dest="minio_root_password",
     required=False,
-    help="Password for minio rootuser"
+    help="Password for minio root user"
 )
-aibrokerArgGroup.add_argument(
-    "--mariadb-user",
-    dest="mariadb_user",
+
+# S3 - General
+# -----------------------------------------------------------------------------
+s3ArgGroup.add_argument(
+    "--s3-provider",
+    dest="aiservice_storage_provider",
     required=False,
-    help="Mariadb user name"
+    help="TODO: Write me"
 )
-aibrokerArgGroup.add_argument(
-    "--mariadb-password",
-    dest="mariadb_password",
+
+# S3 - Bucket Naming
+# -----------------------------------------------------------------------------
+s3ArgGroup.add_argument(
+    "--s3-pipelines-bucket",
+    dest="aiservice_storage_pipelines_bucket",
     required=False,
-    help="Password for mariadb user"
+    default="km-pipelines",
+    help="TODO: Write me"
 )
+s3ArgGroup.add_argument(
+    "--s3-tenants-bucket",
+    dest="aiservice_storage_tenants_bucket",
+    required=False,
+    default="km-tenants",
+    help="TODO: Write me"
+)
+s3ArgGroup.add_argument(
+    "--s3-templates-bucket",
+    dest="aiservice_storage_templates_bucket",
+    required=False,
+    default="km-templates",
+    help="TODO: Write me"
+)
+
+# S3 - Bucket Prefixes
+# -----------------------------------------------------------------------------
+s3ArgGroup.add_argument(
+    "--s3-bucket-prefix",
+    dest="aiservice_s3_bucket_prefix",
+    required=False,
+    default="s3",
+    help="s3 bucket prefix"
+)
+s3ArgGroup.add_argument(
+    "--s3-bucket-prefix-tenant",
+    dest="aiservice_tenant_s3_bucket_prefix",
+    required=False,
+    default="s3",
+    help="s3 bucket prefix ( tenant level )"
+)
+
+# S3 - External Connection
+# -----------------------------------------------------------------------------
+s3ArgGroup.add_argument(
+    "--s3-host",
+    dest="aiservice_storage_host",
+    required=False,
+    help="TODO: Write me"
+)
+s3ArgGroup.add_argument(
+    "--s3-port",
+    dest="aiservice_storage_port",
+    required=False,
+    help="TODO: Write me"
+)
+s3ArgGroup.add_argument(
+    "--s3-ssl",
+    dest="aiservice_storage_ssl",
+    required=False,
+    help="TODO: Write me"
+)
+s3ArgGroup.add_argument(
+    "--s3-accesskey",
+    dest="aiservice_storage_accesskey",
+    required=False,
+    help="TODO: Write me"
+)
+s3ArgGroup.add_argument(
+    "--s3-secretkey",
+    dest="aiservice_storage_secretkey",
+    required=False,
+    help="TODO: Write me"
+)
+s3ArgGroup.add_argument(
+    "--s3-region",
+    dest="aiservice_storage_region",
+    required=False,
+    help="TODO: Write me"
+)
+s3ArgGroup.add_argument(
+    "--s3-endpoint-url",
+    dest="aiservice_s3_endpoint_url",
+    required=False,
+    help="endpoint url for s3"
+)
+
+# S3 - External Access Credentials (Tenant)
+# -----------------------------------------------------------------------------
+s3ArgGroup.add_argument(
+    "--s3-tenant-access-key",
+    dest="aiservice_tenant_s3_access_key",
+    required=False,
+    help="access key for s3 ( tenant level )"
+)
+s3ArgGroup.add_argument(
+    "--s3-tenant-secret-key",
+    dest="aiservice_tenant_s3_secret_key",
+    required=False,
+    help="secret key for s3 ( tenant level )"
+)
+s3ArgGroup.add_argument(
+    "--s3-tenant-region",
+    dest="aiservice_tenant_s3_region",
+    required=False,
+    help="s3 region ( tenant level )"
+)
+s3ArgGroup.add_argument(
+    "--s3-tenant-endpoint-url",
+    dest="aiservice_tenant_s3_endpoint_url",
+    required=False,
+    help="endpoint url for s3 ( tenant level )"
+)
+
+# Watsonx
+# -----------------------------------------------------------------------------
+watsonxArgGroup = aiServiceinstallArgParser.add_argument_group("Watsonx")
+
+watsonxArgGroup.add_argument(
+    "--watsonxai-apikey",
+    dest="aiservice_watsonxai_apikey",
+    required=False,
+    help="TODO: Write me"
+)
+watsonxArgGroup.add_argument(
+    "--watsonxai-url",
+    dest="aiservice_watsonxai_url",
+    required=False,
+    help="TODO: Write me"
+)
+watsonxArgGroup.add_argument(
+    "--watsonxai-project-id",
+    dest="aiservice_watsonxai_project_id",
+    required=False,
+    help="TODO: Write me"
+)
+watsonxArgGroup.add_argument(
+    "--watsonx-action",
+    dest="aiservice_watsonx_action",
+    required=False,
+    help="TODO: Write me"
+)
+
+
+# AI Service
+# -----------------------------------------------------------------------------
 aibrokerArgGroup.add_argument(
     "--tenant-entitlement-type",
     dest="tenant_entitlement_type",
@@ -348,54 +373,6 @@ aibrokerArgGroup.add_argument(
     required=False,
     help="End date for Aibroker tenant"
 )
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-s3-bucket-prefix",
-    dest="mas_aibroker_s3_bucket_prefix",
-    required=False,
-    help="s3 bucker prefix"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-s3-endpoint-url",
-    dest="mas_aibroker_s3_endpoint_url",
-    required=False,
-    help="endpoint url for s3"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-s3-region",
-    dest="mas_aibroker_s3_region",
-    required=False,
-    help="region for s3"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-tenant-s3-bucket-prefix",
-    dest="mas_aibroker_tenant_s3_bucket_prefix",
-    required=False,
-    help="s3 bucker prefix ( tenant level )"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-tenant-s3-region",
-    dest="mas_aibroker_tenant_s3_region",
-    required=False,
-    help="s3 region ( tenant level )"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-tenant-s3-endpoint-url",
-    dest="mas_aibroker_tenant_s3_endpoint_url",
-    required=False,
-    help="endpoint url for s3 ( tenant level )"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-tenant-s3-access-key",
-    dest="mas_aibroker_tenant_s3_access_key",
-    required=False,
-    help="access key for s3 ( tenant level )"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-tenant-s3-secret-key",
-    dest="mas_aibroker_tenant_s3_secret_key",
-    required=False,
-    help="secret key for s3 ( tenant level )"
-)
 aibrokerArgGroup.add_argument(
     "--rsl-url",
     dest="rsl_url",
@@ -414,112 +391,6 @@ aibrokerArgGroup.add_argument(
     required=False,
     help="token for rsl"
 )
-aibrokerArgGroup.add_argument(
-    "--install-minio-aiservice",
-    dest="install_minio_aiservice",
-    required=False,
-    help="flag for install minio"
-)
-aibrokerArgGroup.add_argument(
-    "--install-sls-aiservice",
-    dest="install_sls_aiservice",
-    required=False,
-    help="flag for install sls"
-)
-aibrokerArgGroup.add_argument(
-    "--install-dro-aiservice",
-    dest="install_dro_aiservice",
-    required=False,
-    help="flag for install dro"
-)
-aibrokerArgGroup.add_argument(
-    "--install-db2-aiservice",
-    dest="install_db2_aiservice",
-    required=False,
-    help="flag for install db2"
-)
-
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-dro-secret-name",
-    dest="mas_aibroker_dro_secret_name",
-    required=False,
-    help="DRO secret name"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-dro-api-key",
-    dest="mas_aibroker_dro_api_key",
-    required=False,
-    help="DRO API key"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-dro-url",
-    dest="mas_aibroker_dro_url",
-    required=False,
-    help="DRO URL"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-dro-ca-cert",
-    dest="mas_aibroker_dro_ca_cert",
-    required=False,
-    help="DRO CA certificate"
-)
-
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-db2-username",
-    dest="mas_aibroker_db2_username",
-    required=False,
-    help="DB2 username"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-db2-password",
-    dest="mas_aibroker_db2_password",
-    required=False,
-    help="DB2 password"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-db2-jdbc-url",
-    dest="mas_aibroker_db2_jdbc_url",
-    required=False,
-    help="DB2 JDBC URL"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-db2-ssl-enabled",
-    dest="mas_aibroker_db2_ssl_enabled",
-    required=False,
-    help="DB2 SSL enabled"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-db2-ca-cert",
-    dest="mas_aibroker_db2_ca_cert",
-    required=False,
-    help="DB2 CA certificate"
-)
-
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-sls-secret-name",
-    dest="mas_aibroker_sls_secret_name",
-    required=False,
-    help="SLS secret name"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-sls-registration-key",
-    dest="mas_aibroker_sls_registration_key",
-    required=False,
-    help="SLS registration key"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-sls-url",
-    dest="mas_aibroker_sls_url",
-    required=False,
-    help="SLS URL"
-)
-aibrokerArgGroup.add_argument(
-    "--mas-aibroker-sls-ca-cert",
-    dest="mas_aibroker_sls_ca_cert",
-    required=False,
-    help="SLS CA certificate"
-)
-
 aibrokerArgGroup.add_argument(
     "--environment-type",
     dest="environment_type",
@@ -527,9 +398,12 @@ aibrokerArgGroup.add_argument(
     default="non-production",
     help="Environment type (default: non-production)"
 )
+
+
 # IBM Db2 Universal Operator
 # -----------------------------------------------------------------------------
 db2ArgGroup = aiServiceinstallArgParser.add_argument_group("IBM Db2 Universal Operator")
+
 db2ArgGroup.add_argument(
     "--db2-namespace",
     required=False,
@@ -540,115 +414,6 @@ db2ArgGroup.add_argument(
     required=False,
     help="Subscription channel for Db2u"
 )
-db2ArgGroup.add_argument(
-    "--db2-system",
-    dest="db2_action_system",
-    required=False,
-    help="Install a shared Db2u instance for MAS (required by IoT & Monitor, supported by Manage)",
-    action="store_const",
-    const="install"
-)
-db2ArgGroup.add_argument(
-    "--db2-manage",
-    dest="db2_action_manage",
-    required=False,
-    help="Install a dedicated Db2u instance for Maximo Manage (supported by Manage)",
-    action="store_const",
-    const="install"
-)
-db2ArgGroup.add_argument(
-    "--db2-facilities",
-    dest="db2_action_facilities",
-    required=False,
-    help="Install a dedicated Db2u instance for Maximo Real Estate and Facilities (supported by Facilities)",
-    action="store_const",
-    const="install"
-)
-db2ArgGroup.add_argument(
-    "--db2-type",
-    required=False,
-    help="Choose the type of the Manage dedicated Db2u instance. Available options are `db2wh` (default) or `db2oltp`"
-)
-db2ArgGroup.add_argument(
-    "--db2-timezone",
-    required=False,
-    help=""
-)
-db2ArgGroup.add_argument(
-    "--db2-affinity-key",
-    required=False,
-    help="Set a node label to declare affinity to"
-)
-db2ArgGroup.add_argument(
-    "--db2-affinity-value",
-    required=False,
-    help="Set the value of the node label to affine with"
-)
-db2ArgGroup.add_argument(
-    "--db2-tolerate-key",
-    required=False,
-    help="Set a node taint to tolerate"
-)
-db2ArgGroup.add_argument(
-    "--db2-tolerate-value",
-    required=False,
-    help="Set the value of the taint to tolerate"
-)
-db2ArgGroup.add_argument(
-    "--db2-tolerate-effect",
-    required=False,
-    help="Set the effect that will be tolerated (NoSchedule, PreferNoSchedule, or NoExecute)"
-)
-db2ArgGroup.add_argument(
-    "--db2-cpu-requests",
-    required=False,
-    help="Customize Db2 CPU request"
-)
-db2ArgGroup.add_argument(
-    "--db2-cpu-limits",
-    required=False,
-    help="Customize Db2 CPU limit"
-)
-db2ArgGroup.add_argument(
-    "--db2-memory-requests",
-    required=False,
-    help="Customize Db2 memory request"
-)
-db2ArgGroup.add_argument(
-    "--db2-memory-limits",
-    required=False,
-    help="Customize Db2 memory limit"
-)
-db2ArgGroup.add_argument(
-    "--db2-backup-storage",
-    dest="db2_backup_storage_size",
-    required=False,
-    help="Customize Db2 storage capacity"
-)
-db2ArgGroup.add_argument(
-    "--db2-data-storage",
-    dest="db2_data_storage_size",
-    required=False,
-    help="Customize Db2 storage capacity"
-)
-db2ArgGroup.add_argument(
-    "--db2-logs-storage",
-    dest="db2_logs_storage_size",
-    required=False,
-    help="Customize Db2 storage capacity"
-)
-db2ArgGroup.add_argument(
-    "--db2-meta-storage",
-    dest="db2_meta_storage_size",
-    required=False,
-    help="Customize Db2 storage capacity"
-)
-db2ArgGroup.add_argument(
-    "--db2-temp-storage",
-    dest="db2_temp_storage_size",
-    required=False,
-    help="Customize Db2 storage capacity"
-)
 
 
 # Development Mode
@@ -669,9 +434,9 @@ devArgGroup.add_argument(
 # -----------------------------------------------------------------------------
 approvalsGroup = aiServiceinstallArgParser.add_argument_group("Integrated Approval Workflow (MAX_RETRIES:RETRY_DELAY:IGNORE_FAILURE)")
 approvalsGroup.add_argument(
-    "--approval-aibroker",
+    "--approval-aiservice",
     default="",
-    help="Require approval after the Aibroker has been configured"
+    help="Require approval after the AI Service has been configured"
 )
 
 # More Options
